@@ -3,6 +3,9 @@
 #' Quickly displays a color scheme returned by [color()].
 #' @param x A [`character`] vector of colors.
 #' @param ... Currently not used.
+#' @return
+#'  `plot()` is called for its side-effects: it results in a graphic
+#'   being displayed (invisibly returns `x`).
 #' @example inst/examples/ex-plot.R
 #' @author N. Frerebeau
 #' @family diagnostic tools
@@ -22,4 +25,6 @@ plot.color_scheme <- function(x, ...) {
   graphics::rect(xleft = seq(0, n - 1), xright = seq(1, n),
                  ybottom = 0.25, ytop = 0.75, col = x, border = NA)
   if (n < 25) graphics::abline(v = seq(1, n), col = "#D3D3D3", lwd = 0.25)
+
+  invisible(x)
 }
